@@ -1,4 +1,4 @@
-/* Copyright (C) 1999-2002 Free Software Foundation, Inc.
+/* Copyright (C) 1999-2003 Free Software Foundation, Inc.
    This file is part of the GNU LIBICONV Library.
 
    The GNU LIBICONV Library is free software; you can redistribute it
@@ -21,12 +21,7 @@
 #ifndef _LIBICONV_H
 #define _LIBICONV_H
 
-#ifdef __APPLE__
-#define LIBICONV_PLUG
-#endif
-
-
-#define _LIBICONV_VERSION 0x0108    /* version number: (major<<8) + minor */
+#define _LIBICONV_VERSION 0x0109    /* version number: (major<<8) + minor */
 extern int _libiconv_version;       /* Likewise */
 
 /* We would like to #include any system header file which could define
@@ -60,7 +55,7 @@ typedef void* iconv_t;
    have EILSEQ in a different header.  On these systems, define EILSEQ
    ourselves. */
 #ifndef EILSEQ
-#define EILSEQ ENOENT
+#define EILSEQ 
 #endif
 
 
@@ -73,8 +68,6 @@ extern "C" {
    encoding `tocode'. */
 #ifndef LIBICONV_PLUG
 #define iconv_open libiconv_open
-#else
-#define libiconv_open iconv_open
 #endif
 extern iconv_t iconv_open (const char* tocode, const char* fromcode);
 
@@ -85,21 +78,17 @@ extern iconv_t iconv_open (const char* tocode, const char* fromcode);
    Decrements `*outbytesleft' and increments `*outbuf' by the same amount. */
 #ifndef LIBICONV_PLUG
 #define iconv libiconv
-#else
-#define libiconv iconv
 #endif
 extern size_t iconv (iconv_t cd, const char* * inbuf, size_t *inbytesleft, char* * outbuf, size_t *outbytesleft);
 
 /* Frees resources allocated for conversion descriptor `cd'. */
 #ifndef LIBICONV_PLUG
 #define iconv_close libiconv_close
-#else
-#define libiconv_close iconv_close
 #endif
 extern int iconv_close (iconv_t cd);
 
 
-#if !defined(LIBICONV_PLUG) || defined(__APPLE__)
+#ifndef LIBICONV_PLUG
 
 /* Nonstandard extensions. */
 
@@ -120,6 +109,17 @@ extern void iconvlist (int (*do_one) (unsigned int namescount,
                                       const char * const * names,
                                       void* data),
                        void* data);
+
+/* Support for relocatable packages.  */
+
+/* Sets the original and the current installation prefix of the package.
+   Relocation simply replaces a pathname starting with the original prefix
+   by the corresponding pathname with the current prefix instead.  Both
+   prefixes should be directory names without trailing slash (i.e. use ""
+   instead of "/").  */
+extern void libiconv_set_relocation_prefix (const char *orig_prefix,
+					    const char *curr_prefix);
+
 #endif
 
 
